@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_apigateway._jsii
 import aws_cdk.aws_dynamodb._jsii
@@ -18,9 +18,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-apigateway-dynamodb",
-    "1.54.0",
+    "1.65.0",
     __name__[0:-6],
-    "aws-apigateway-dynamodb@1.54.0.jsii.tgz",
+    "aws-apigateway-dynamodb@1.65.0.jsii.tgz",
 )
 
 __all__ = [
